| Title: | skittles data from possibly-wrong/skittles as R data |
|---|---|
| Description: | Provides skittles packet data as a ready dataset for use with R. |
| Authors: | Fran Barton [ctb, cre] (ORCID: <https://orcid.org/0000-0002-5650-1176>), Possibly Wrong [aut, dtc] |
| Maintainer: | Fran Barton <[email protected]> |
| License: | Unlicense + file UNLICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-20 06:48:04 UTC |
| Source: | https://github.com/francisbarton/skittles |
Columns 2-7 are the original data from Possibly Wrong, with the column names converted to lower case. I added a "pack_id" key field as column 1, which is just the row number zero-padded to a 3-digit character. (This is to avoid it being mistaken for a numeric data field.) No other data cleaning has been done; all the original columns read in cleanly as integer vectors. This data is provided as a tibble rather than as a plain data.frame.
This 'tidy' version of the dataset has also been exported to inst/ as
skittles.csv
The original data from Possibly Wrong is a tab-separated .txt file with
the field names in row 1 in title case, eg "Lemon".
The skittles dataset is a tidied version of this, but skittles_raw
retains the original field names and has no ID column added.
The numerical data is identical however.
This version of the dataset has also been exported to inst/ as
skittles_raw.tsv
skittles skittles_rawskittles skittles_raw
A tibble with 468 rows and 7 columns:
A unique 3-character ID code for each row
Skittle counts (integer) per pack, for each colour/flavour
Number of uncounted fragments of possibly inedible matter, or a chunk with no identifiable single colour. See the blog post linked below for the detail of this fascinating methodological decision.
A data.frame with 468 rows and 6 columns:
Skittle counts (integer) per pack, for each colour/flavour
Number of uncounted fragments of possibly inedible matter, or a chunk with no identifiable single colour. See the blog post linked below for the detail of this fascinating methodological decision.
https://github.com/possibly-wrong/skittles